==> tim_ui_kit_calling_plugin-0.3.3.tar.gz: lib/model/TIMUIKitCallingListener.dart <==
// ignore_for_file: prefer_function_declarations_over_variables

import 'package:tim_ui_kit_calling_plugin/model/TIMUIKitInvitedParams.dart';

class TUICallingListener {
  OnInvited onInvited = (InviteParams params) {};
  OnReject onReject = (RejectParams params) {};
  OnNoResp onNoResp = (NoRespParams params) {};
  OnGroupCallInviteeListUpdate onGroupCallInviteeListUpdate =
      (OnGroupCallInviteeListUpdateParams params) {};
  OnUserLeave onUserLeave = (OnUserLeaveParams params) {};
  OnUserEnter onUserEnter = (OnUserEnterParams params) {};
  OnLineBusy onLineBusy = (OnLineBusyParams prams) {};
  OnCallEnd onCallEnd = () {};
  OnCallingTimeout onCallingTimeout = (OnCallingTimeoutParams params) {};
  OnCallingCancel onCallingCancel = () {};
  OnUserVideoAvailable onUserVideoAvailable =
      (OnUserVideoAvailableParams params) {};
  OnUserAudioAvailable onUserAudioAvailable =
      (OnUserAudioAvailableParams params) {};
  OnKickedOffline onKickedOffline = () {};
  OnEnterRoom onEnterRoom = (int time) {};
  OnWarning onWarning = (OnWarningPrams params) {};
  OnError onError = (OnErrorParams params) {};
  OnUserVoiceVolume onUserVoiceVolume = (dynamic params) {};

  TUICallingListener(
      {OnInvited? onInvited,
      OnLineBusy? onLineBusy,
      OnCallEnd? onCallEnd,
      OnGroupCallInviteeListUpdate? onGroupCallInviteeListUpdate,
      OnCallingCancel? onCallingCancel,
      OnCallingTimeout? onCallingTimeout,
      OnKickedOffline? onKickedOffline,
      OnNoResp? onNoResp,
      OnReject? onReject,
      OnUserVoiceVolume? onUserVoiceVolume,
      OnUserAudioAvailable? onUserAudioAvailable,
      OnUserVideoAvailable? onUserVideoAvailable,
      OnEnterRoom? onEnterRoom,
      OnWarning? onWarning,
      OnUserEnter? onUserEnter,
      OnError? onError,
      OnUserLeave? onUserLeave}) {
    if (onCallEnd != null) {
      this.onCallEnd = onCallEnd;
    }
    if (onInvited != null) {
      this.onInvited = onInvited;
    }

    if (onUserVoiceVolume != null) {
      this.onUserVoiceVolume = onUserVoiceVolume;
    }

    if (onWarning != null) {
      this.onWarning = onWarning;
    }

    if (onError != null) {
      this.onError = onError;
    }

    if (onGroupCallInviteeListUpdate != null) {
      this.onGroupCallInviteeListUpdate = onGroupCallInviteeListUpdate;
    }

    if (onLineBusy != null) {
      this.onLineBusy = onLineBusy;
    }
    if (onCallingCancel != null) {
      this.onCallingCancel = onCallingCancel;
    }

    if (onCallingTimeout != null) {
      this.onCallingTimeout = onCallingTimeout;
    }

    if (onKickedOffline != null) {
      this.onKickedOffline = onKickedOffline;
    }
    if (onNoResp != null) {
      this.onNoResp = onNoResp;
    }
    if (onReject != null) {
      this.onReject = onReject;
    }
    if (onUserAudioAvailable != null) {
      this.onUserAudioAvailable = onUserAudioAvailable;
    }

    if (onUserEnter != null) {
      this.onUserEnter = onUserEnter;
    }

    if (onUserLeave != null) {
      this.onUserLeave = onUserLeave;
    }
    if (onUserVideoAvailable != null) {
      this.onUserVideoAvailable = onUserVideoAvailable;
    }

    if (onEnterRoom != null) {
      this.onEnterRoom = onEnterRoom;
    }
  }
}

==> tim_ui_kit_calling_plugin-1.0.2.tar.gz: lib/model/TIMUIKitCallingListener.dart <==
// ignore_for_file: prefer_function_declarations_over_variables

import 'package:tim_ui_kit_calling_plugin/model/TIMUIKitInvitedParams.dart';

class TUICallingListener {
  OnInvited onInvited = (InviteParams params) {};
  OnReject onReject = (RejectParams params) {};
  OnNoResp onNoResp = (NoRespParams params) {};
  OnGroupCallInviteeListUpdate onGroupCallInviteeListUpdate =
      (OnGroupCallInviteeListUpdateParams params) {};
  OnUserLeave onUserLeave = (OnUserLeaveParams params) {};
  OnUserEnter onUserEnter = (OnUserEnterParams params) {};
  OnLineBusy onLineBusy = (OnLineBusyParams prams) {};
  OnCallEnd onCallEnd = () {};
  OnCallingTimeout onCallingTimeout = (OnCallingTimeoutParams params) {};
  OnCallingCancel onCallingCancel = () {};
  OnUserVideoAvailable onUserVideoAvailable =
      (OnUserVideoAvailableParams params) {};
  OnUserAudioAvailable onUserAudioAvailable =
      (OnUserAudioAvailableParams params) {};
  OnKickedOffline onKickedOffline = () {};
  OnEnterRoom onEnterRoom = (int time) {};
  OnWarning onWarning = (OnWarningPrams params) {};
  OnError onError = (OnErrorParams params) {};
  OnUserVoiceVolume onUserVoiceVolume = (dynamic params) {};
  OnAccept onAccept = (AcceptParams params) {};

  TUICallingListener({
    OnInvited? onInvited,
    OnLineBusy? onLineBusy,
    OnCallEnd? onCallEnd,
    OnGroupCallInviteeListUpdate? onGroupCallInviteeListUpdate,
    OnCallingCancel? onCallingCancel,
    OnCallingTimeout? onCallingTimeout,
    OnKickedOffline? onKickedOffline,
    OnNoResp? onNoResp,
    OnReject? onReject,
    OnUserVoiceVolume? onUserVoiceVolume,
    OnUserAudioAvailable? onUserAudioAvailable,
    OnUserVideoAvailable? onUserVideoAvailable,
    OnEnterRoom? onEnterRoom,
    OnWarning? onWarning,
    OnUserEnter? onUserEnter,
    OnError? onError,
    OnUserLeave? onUserLeave,
    OnAccept? onAccept,
  }) {
    if (onCallEnd != null) {
      this.onCallEnd = onCallEnd;
    }
    if (onInvited != null) {
      this.onInvited = onInvited;
    }

    if (onUserVoiceVolume != null) {
      this.onUserVoiceVolume = onUserVoiceVolume;
    }

    if (onWarning != null) {
      this.onWarning = onWarning;
    }

    if (onError != null) {
      this.onError = onError;
    }

    if (onGroupCallInviteeListUpdate != null) {
      this.onGroupCallInviteeListUpdate = onGroupCallInviteeListUpdate;
    }

    if (onLineBusy != null) {
      this.onLineBusy = onLineBusy;
    }
    if (onCallingCancel != null) {
      this.onCallingCancel = onCallingCancel;
    }

    if (onCallingTimeout != null) {
      this.onCallingTimeout = onCallingTimeout;
    }

    if (onKickedOffline != null) {
      this.onKickedOffline = onKickedOffline;
    }
    if (onNoResp != null) {
      this.onNoResp = onNoResp;
    }
    if (onReject != null) {
      this.onReject = onReject;
    }
    if (onUserAudioAvailable != null) {
      this.onUserAudioAvailable = onUserAudioAvailable;
    }

    if (onUserEnter != null) {
      this.onUserEnter = onUserEnter;
    }

    if (onUserLeave != null) {
      this.onUserLeave = onUserLeave;
    }
    if (onUserVideoAvailable != null) {
      this.onUserVideoAvailable = onUserVideoAvailable;
    }

    if (onEnterRoom != null) {
      this.onEnterRoom = onEnterRoom;
    }

    if(onAccept != null){
      this.onAccept = onAccept;
    }
  }
}
